@@ -383,6 +383,31 @@ public class Generator
               facadeHelper.setCompilerCompliance("13"); 
               break;
             }
+            case JDK140_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("14"); 
+              break;
+            }
+            case JDK150_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("15"); 
+              break;
+            }
+            case JDK160_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("16"); 
+              break;
+            }
+            case JDK170_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("17"); 
+              break;
+            }
+            case JDK180_LITERAL:
+            {
+              facadeHelper.setCompilerCompliance("18"); 
+              break;
+            }
           }
 
           if (genModel.isCodeFormatting())
